class Curso < ActiveRecord::Base

  hobo_model # Don't put anything above this

  fields do
    titulo :string, :name => true
    fecha  :date
    lugar  :string
    descripcion :text
    fecha_cierre :date
    timestamps
  end

  # --- Relaciones --- #
  has_many :curso_alumnos, :dependent => :destroy
  has_many :categoria_cursos, :dependent => :destroy
  has_many :categorias, :through => :categoria_cursos, :accessible => true
  has_many :alumnos, :through => :curso_alumnos
  
  # --- Búsquedas --- #
  set_search_columns :titulo, :lugar
  
  
  # --- Ciclo de vida --- #
  lifecycle :state_field => :estado do
    state :cerrado, :default => :true
    state :abierto

    transition :abrir_curso, { :cerrado => :abierto }, :available_to => :all
    transition :cerrar_curso, { :abierto => :cerrado }, :available_to => :all do
      self.update_attribute(:fecha_cierre, Date.today)
    end
  end
  
  # Asignamos colores a los estados
  def color
    case estado
    when "cerrado"
      "#FFF8B0" #Amarillo
    when "abierto"
      "#A5FFAA" #Verde
    else
      ""
    end
  end


  # --- Permissions --- #

  def create_permitted?
    acting_user.administrator?
  end

  def update_permitted?
    acting_user.administrator?
  end

  def destroy_permitted?
    acting_user.administrator?
  end

  def view_permitted?(field)
    true
  end

end
